==> android-sdk-2.4.0.7-sources.jar: io/adbrix/sdk/data/modelprovider/EventModelProvider.java <==
package io.adbrix.sdk.data.modelprovider;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;

import io.adbrix.sdk.component.AbxLog;
import io.adbrix.sdk.component.IUserPropertyManager;
import io.adbrix.sdk.data.entity.DataRegistryKey;
import io.adbrix.sdk.data.repository.DataRegistry;
import io.adbrix.sdk.domain.CoreConstants;
import io.adbrix.sdk.domain.model.EventModel;
import io.adbrix.sdk.domain.model.LogEventParameter;
import io.adbrix.sdk.domain.model.UserPropertyModel;
import io.adbrix.sdk.utils.CommonUtils;

public class EventModelProvider implements IDataModelProvider<EventModel> {
    IUserPropertyManager userPropertyManager;
    DataRegistry dataRegistry;
    LogEventParameter logEventParameter;

    public EventModelProvider(
            IUserPropertyManager userPropertyManager,
            DataRegistry dataRegistry) {
        this.userPropertyManager = userPropertyManager;
        this.dataRegistry = dataRegistry;
    }

    public void setLogEventParameter(LogEventParameter logEventParameter) {
        this.logEventParameter = logEventParameter;
    }

    @Override
    public EventModel provide() {

        EventModel.Location location = new EventModel.Location(
                this.dataRegistry.safeGetString(DataRegistryKey.STRING_LOCATION_LWID, null),
                this.dataRegistry.safeGetDouble(DataRegistryKey.DOUBLE_LOCATION_LAT, 0.0d),
                this.dataRegistry.safeGetDouble(DataRegistryKey.DOUBLE_LOCATION_LNG, 0.0d)
        );

        UserPropertyModel userPropertyModel = this.userPropertyManager.getCurrentUserPropertyModel();
        if(!CoreConstants.EVENT_ADID_CHANGED.equals(logEventParameter.eventName)){
            putOrderNumbersToEventParam(logEventParameter);
        }

        EventModel eventModel = new EventModel(
                this.dataRegistry.safeGetString(DataRegistryKey.STRING_LAST_FIRSTOPEN_ID, null),
                this.dataRegistry.safeGetString(DataRegistryKey.STRING_LAST_DEEPLINK_ID, null),
                this.dataRegistry.safeGetString(DataRegistryKey.STRING_LAST_OPEN_ID, null),
                getPrevId(logEventParameter),
                getEventDatetime(logEventParameter),
                logEventParameter.group,
                logEventParameter.eventName,
                logEventParameter.eventParam,
                logEventParameter.sessionInterval,
                logEventParameter.sessionLength,
                logEventParameter.eventId,
                getSessionId(logEventParameter.eventName),
                location,
                userPropertyModel.userSnapshotId,
                getUserPropertyJSONObject(userPropertyModel),
                getCiJSONObject(userPropertyModel)
        );
        return eventModel;
    }

    private String getPrevId(LogEventParameter logEventParameter) {
        if (logEventParameter.prevId != null)
            return logEventParameter.prevId;
        else
            return this.dataRegistry.safeGetString(DataRegistryKey.STRING_PREV_ID, null);
    }

    private String getEventDatetime(LogEventParameter logEventParameter) {
        if (logEventParameter.eventDatetime == null)
            return CommonUtils.getCurrentUTCInDBFormat();
        else
            return logEventParameter.eventDatetime;
    }

    private String getSessionId(String sessionType) {
        if (CoreConstants.EVENT_END_SESSION.equals(sessionType)) {
            return this.dataRegistry.safeGetString(DataRegistryKey.STRING_LAST_END_SESSION_ID, null);
        }
        return this.dataRegistry.safeGetString(DataRegistryKey.STRING_LAST_CREATED_SESSION_ID, null);
    }

    private JSONObject getUserPropertyJSONObject(UserPropertyModel userPropertyModel) {
        JSONObject userPropertyJson = new JSONObject();
        try {
            for (Map.Entry<String, Object> entry : userPropertyModel.properties.entrySet()) {
                String key = entry.getKey();
                Object value = entry.getValue();

                if (!key.startsWith(CoreConstants.CI_KEY)) {
                    if (CoreConstants.ABX_USER_PROPERTY_KEY_LIST.contains(key)) {
                        userPropertyJson.put(key, value);
                    } else{
                        userPropertyJson.put("c:" + key, value);
                    }
                }
            }
        } catch (JSONException e) {
            AbxLog.e(e, true);
        }

        return userPropertyJson;
    }

    private JSONObject getCiJSONObject(UserPropertyModel userPropertyModel) {
        JSONObject ciJson = new JSONObject();
        try {
            for (Map.Entry<String, Object> entry : userPropertyModel.properties.entrySet()) {
                String key = entry.getKey();
                Object value = entry.getValue();

                if (key.startsWith(CoreConstants.CI_KEY)) {
                    key = key.replace(CoreConstants.CI_KEY, "");
                    if (CoreConstants.ABX_CI_KEY_LIST.contains(key)) {
                        ciJson.put("abx:" + key, value);
                    } else {
                        ciJson.put("c:" + key, value);
                    }
                }
            }
        } catch (JSONException e) {
            AbxLog.e(e, true);
        }

        return ciJson;
    }

    private long getSessionOrderNo(LogEventParameter logEventParameter) {

        boolean isEndSessionNotSentBeforeUpdate = CoreConstants.EVENT_END_SESSION.equals(logEventParameter.eventName) &&
                dataRegistry.safeGetLong(DataRegistryKey.LONG_SESSION_ORDER_NO, 0L) == 0L;

        if (isEndSessionNotSentBeforeUpdate)
            return 0L;

        if (logEventParameter.sessionOrderNo != 0L)
            return logEventParameter.sessionOrderNo;

        return dataRegistry.incrementAndGetLong(DataRegistryKey.LONG_SESSION_ORDER_NO);
    }

    private long getEventOrderNo(LogEventParameter logEventParameter) {
        if (logEventParameter.eventOrderNo != 0L)
            return logEventParameter.eventOrderNo;

        return dataRegistry.incrementAndGetLong(DataRegistryKey.LONG_EVENT_ORDER_NO);
    }

    private void putOrderNumbersToEventParam(LogEventParameter logEventParameter) {
        if (logEventParameter.eventParam == null) {
            logEventParameter.eventParam = new HashMap<>();
        }

        long sessionOrderNo = getSessionOrderNo(logEventParameter);
        AbxLog.d(logEventParameter.eventName + ":"+sessionOrderNo,true);

        if (sessionOrderNo > 0)
            logEventParameter.eventParam.put(CoreConstants.SESSION_ORDER_NO, "long:" + sessionOrderNo);

        logEventParameter.eventParam.put(CoreConstants.EVENT_ORDER_NO, "long:" + getEventOrderNo(logEventParameter));
    }
}

==> android-sdk-2.5.0.1-sources.jar: io/adbrix/sdk/data/modelprovider/EventModelProvider.java <==
package io.adbrix.sdk.data.modelprovider;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;

import io.adbrix.sdk.component.AbxLog;
import io.adbrix.sdk.component.IUserPropertyManager;
import io.adbrix.sdk.data.entity.DataRegistryKey;
import io.adbrix.sdk.data.repository.DataRegistry;
import io.adbrix.sdk.domain.CoreConstants;
import io.adbrix.sdk.domain.model.EventModel;
import io.adbrix.sdk.domain.model.LogEventParameter;
import io.adbrix.sdk.domain.model.UserPropertyModel;
import io.adbrix.sdk.utils.CommonUtils;

public class EventModelProvider implements IDataModelProvider<EventModel> {
    IUserPropertyManager userPropertyManager;
    DataRegistry dataRegistry;
    LogEventParameter logEventParameter;

    public EventModelProvider(
            IUserPropertyManager userPropertyManager,
            DataRegistry dataRegistry) {
        this.userPropertyManager = userPropertyManager;
        this.dataRegistry = dataRegistry;
    }

    public void setLogEventParameter(LogEventParameter logEventParameter) {
        this.logEventParameter = logEventParameter;
    }

    @Override
    public EventModel provide() {

        EventModel.Location location = new EventModel.Location(
                this.dataRegistry.safeGetString(DataRegistryKey.STRING_LOCATION_LWID, null),
                this.dataRegistry.safeGetDouble(DataRegistryKey.DOUBLE_LOCATION_LAT, 0.0d),
                this.dataRegistry.safeGetDouble(DataRegistryKey.DOUBLE_LOCATION_LNG, 0.0d)
        );

        UserPropertyModel userPropertyModel = this.userPropertyManager.getCurrentUserPropertyModel();
        putOrderNumbersToEventParam(logEventParameter);

        EventModel eventModel = new EventModel(
                this.dataRegistry.safeGetString(DataRegistryKey.STRING_LAST_FIRSTOPEN_ID, null),
                this.dataRegistry.safeGetString(DataRegistryKey.STRING_LAST_DEEPLINK_ID, null),
                this.dataRegistry.safeGetString(DataRegistryKey.STRING_LAST_OPEN_ID, null),
                getPrevId(logEventParameter),
                getEventDatetime(logEventParameter),
                logEventParameter.group,
                logEventParameter.eventName,
                logEventParameter.eventParam,
                logEventParameter.sessionInterval,
                logEventParameter.sessionLength,
                logEventParameter.eventId,
                getSessionId(logEventParameter.eventName),
                location,
                userPropertyModel.userSnapshotId,
                getUserPropertyJSONObject(userPropertyModel),
                getCiJSONObject(userPropertyModel)
        );
        return eventModel;
    }

    private String getPrevId(LogEventParameter logEventParameter) {
        if (logEventParameter.prevId != null)
            return logEventParameter.prevId;
        else
            return this.dataRegistry.safeGetString(DataRegistryKey.STRING_PREV_ID, null);
    }

    private String getEventDatetime(LogEventParameter logEventParameter) {
        if (logEventParameter.eventDatetime == null)
            return CommonUtils.getCurrentUTCInDBFormat();
        else
            return logEventParameter.eventDatetime;
    }

    private String getSessionId(String sessionType) {
        if (CoreConstants.EVENT_END_SESSION.equals(sessionType)) {
            return this.dataRegistry.safeGetString(DataRegistryKey.STRING_LAST_END_SESSION_ID, null);
        }
        return this.dataRegistry.safeGetString(DataRegistryKey.STRING_LAST_CREATED_SESSION_ID, null);
    }

    private JSONObject getUserPropertyJSONObject(UserPropertyModel userPropertyModel) {
        JSONObject userPropertyJson = new JSONObject();
        try {
            for (Map.Entry<String, Object> entry : userPropertyModel.properties.entrySet()) {
                String key = entry.getKey();
                Object value = entry.getValue();

                if (!key.startsWith(CoreConstants.CI_KEY)) {
                    if (CoreConstants.ABX_USER_PROPERTY_KEY_LIST.contains(key)) {
                        userPropertyJson.put(key, value);
                    } else if (CoreConstants.ABX_DEPRECATED_USER_PROPERTY_KEY_LIST.contains(key)) {
                        userPropertyJson.put("abx:" + key, value);
                    }
                    else{
                        userPropertyJson.put("c:" + key, value);
                    }
                }
            }
        } catch (JSONException e) {
            AbxLog.e(e, true);
        }

        return userPropertyJson;
    }

    private JSONObject getCiJSONObject(UserPropertyModel userPropertyModel) {
        JSONObject ciJson = new JSONObject();
        try {
            for (Map.Entry<String, Object> entry : userPropertyModel.properties.entrySet()) {
                String key = entry.getKey();
                Object value = entry.getValue();

                if (key.startsWith(CoreConstants.CI_KEY)) {
                    key = key.replace(CoreConstants.CI_KEY, "");
                    if (CoreConstants.ABX_CI_KEY_LIST.contains(key)) {
                        ciJson.put("abx:" + key, value);
                    } else {
                        ciJson.put("c:" + key, value);
                    }
                }
            }
        } catch (JSONException e) {
            AbxLog.e(e, true);
        }

        return ciJson;
    }

    private long getSessionOrderNo(LogEventParameter logEventParameter) {

        boolean isEndSessionNotSentBeforeUpdate = CoreConstants.EVENT_END_SESSION.equals(logEventParameter.eventName) &&
                dataRegistry.safeGetLong(DataRegistryKey.LONG_SESSION_ORDER_NO, 0L) == 0L;

        if (isEndSessionNotSentBeforeUpdate)
            return 0L;

        if (logEventParameter.sessionOrderNo != 0L)
            return logEventParameter.sessionOrderNo;

        return dataRegistry.incrementAndGetLong(DataRegistryKey.LONG_SESSION_ORDER_NO);
    }

    private long getEventOrderNo(LogEventParameter logEventParameter) {
        if (logEventParameter.eventOrderNo != 0L)
            return logEventParameter.eventOrderNo;

        return dataRegistry.incrementAndGetLong(DataRegistryKey.LONG_EVENT_ORDER_NO);
    }

    private void putOrderNumbersToEventParam(LogEventParameter logEventParameter) {
        if (logEventParameter.eventParam == null) {
            logEventParameter.eventParam = new HashMap<>();
        }

        long sessionOrderNo = getSessionOrderNo(logEventParameter);
        AbxLog.d(logEventParameter.eventName + ":"+sessionOrderNo,true);

        if (sessionOrderNo > 0)
            logEventParameter.eventParam.put(CoreConstants.SESSION_ORDER_NO, "long:" + sessionOrderNo);

        logEventParameter.eventParam.put(CoreConstants.EVENT_ORDER_NO, "long:" + getEventOrderNo(logEventParameter));
    }
}
